/*
 * GQmpeg
 * (C) 2002 John Ellis
 *
 * Author: John Ellis
 *
 * This software is released under the GNU General Public License (GNU GPL).
 * Please read the included file COPYING for more information.
 * This software comes with no warranty of any kind, use at your own risk!
 */


#ifndef DNDUTIL_H
#define DNDUTIL_H


GList *uri_get_list(gchar *data);
gchar *uri_create_text(GList *list, gint *t, gint plain_text);
void uri_parse_encoded_chars(GList *list);
void dnd_init(void);


#endif
